<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 7/15/2012	ELL
// 
// 
//
//

	include ("check_session.php");

	$user_table = $_POST['user_table'];
	$welcome_message_page = $_POST['welcome_message_page'];
	$_SESSION['last_user_table'] = $user_table;
	
	$query = "UPDATE `" . $user_table . "` SET `welcome_message_page`='" . $welcome_message_page . "'";
	$cnt = $bwb_dbh->exec($query);
	
	echo "Welcome message page added";

?>
